@@ -1,16 +1,16 @@
-st3[60] = {
-    "HemoNpoints": 100, 
-    "RhythmDescription": "Sinus bradycardia with severe ST depression", 
-    "RhythmRate": 60, 
+st1[50] = {
+    "HemoNpoints": 120, 
+    "RhythmDescription": "Sinus bradcardia with T wave flattening", 
+    "RhythmRate": 50, 
     "hemoPoints": [
         {
-            "AbpHt": -2, 
+            "AbpHt": -1, 
             "CvpHt": 0, 
             "EcgIIHt": 0, 
             "EcgTag": 0, 
             "EcgV5Ht": 0, 
-            "PapHt": -4, 
-            "SpHt": -3
+            "PapHt": -3, 
+            "SpHt": -2
         }, 
         {
             "AbpHt": -1, 
@@ -210,217 +210,217 @@ st3[60] = {
             "PapHt": 0, 
             "SpHt": 0
         }, 
+        {
+            "AbpHt": 0, 
+            "CvpHt": -3, 
+            "EcgIIHt": 2, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 3, 
+            "PapHt": 0, 
+            "SpHt": 0
+        }, 
+        {
+            "AbpHt": 0, 
+            "CvpHt": -3, 
+            "EcgIIHt": 1, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 1, 
+            "PapHt": 0, 
+            "SpHt": 0
+        }, 
         {
             "AbpHt": 0, 
             "CvpHt": -3, 
             "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 0, 
-            "PapHt": 0, 
-            "SpHt": 0
-        }, 
-        {
-            "AbpHt": 0, 
-            "CvpHt": -3, 
-            "EcgIIHt": 3, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 4, 
-            "PapHt": 0, 
-            "SpHt": 0
-        }, 
-        {
-            "AbpHt": 0, 
-            "CvpHt": -3, 
-            "EcgIIHt": 4, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 5, 
+            "EcgV5Ht": 1, 
             "PapHt": 0, 
             "SpHt": 0
         }, 
         {
             "AbpHt": 0, 
             "CvpHt": -2, 
-            "EcgIIHt": 5, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 6, 
+            "EcgV5Ht": 0, 
             "PapHt": -1, 
             "SpHt": 0
         }, 
         {
             "AbpHt": -1, 
             "CvpHt": -2, 
-            "EcgIIHt": 5, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 6, 
+            "EcgV5Ht": 0, 
             "PapHt": -1, 
             "SpHt": 0
         }, 
         {
             "AbpHt": -1, 
             "CvpHt": -1, 
-            "EcgIIHt": 6, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 6, 
+            "EcgV5Ht": 0, 
             "PapHt": -4, 
             "SpHt": 0
         }, 
         {
             "AbpHt": -1, 
             "CvpHt": -1, 
-            "EcgIIHt": 6, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 6, 
+            "EcgV5Ht": 0, 
             "PapHt": -9, 
             "SpHt": -1
         }, 
         {
             "AbpHt": -4, 
             "CvpHt": 0, 
-            "EcgIIHt": 6, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 6, 
+            "EcgV5Ht": 0, 
             "PapHt": -18, 
             "SpHt": -1
         }, 
         {
             "AbpHt": -9, 
             "CvpHt": 0, 
-            "EcgIIHt": 7, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 6, 
+            "EcgV5Ht": 0, 
             "PapHt": -19, 
             "SpHt": -2
         }, 
         {
             "AbpHt": -18, 
             "CvpHt": 1, 
-            "EcgIIHt": 7, 
+            "EcgIIHt": -1, 
             "EcgTag": 0, 
-            "EcgV5Ht": 7, 
+            "EcgV5Ht": -1, 
             "PapHt": -20, 
             "SpHt": -4
         }, 
         {
             "AbpHt": -19, 
             "CvpHt": 1, 
-            "EcgIIHt": 8, 
+            "EcgIIHt": -1, 
             "EcgTag": 0, 
-            "EcgV5Ht": 7, 
+            "EcgV5Ht": -1, 
             "PapHt": -20, 
             "SpHt": -7
         }, 
         {
             "AbpHt": -20, 
             "CvpHt": 2, 
-            "EcgIIHt": 8, 
+            "EcgIIHt": -1, 
             "EcgTag": 0, 
-            "EcgV5Ht": 7, 
+            "EcgV5Ht": -1, 
             "PapHt": -19, 
             "SpHt": -10
         }, 
         {
             "AbpHt": -20, 
             "CvpHt": 2, 
-            "EcgIIHt": 8, 
+            "EcgIIHt": -2, 
             "EcgTag": 0, 
-            "EcgV5Ht": 8, 
+            "EcgV5Ht": -1, 
             "PapHt": -17, 
             "SpHt": -13
         }, 
         {
             "AbpHt": -19, 
             "CvpHt": 3, 
-            "EcgIIHt": 9, 
+            "EcgIIHt": -2, 
             "EcgTag": 0, 
-            "EcgV5Ht": 8, 
+            "EcgV5Ht": -1, 
             "PapHt": -16, 
             "SpHt": -15
         }, 
         {
             "AbpHt": -17, 
             "CvpHt": 3, 
-            "EcgIIHt": 9, 
+            "EcgIIHt": -3, 
             "EcgTag": 0, 
-            "EcgV5Ht": 8, 
+            "EcgV5Ht": -2, 
             "PapHt": -15, 
             "SpHt": -16
         }, 
         {
             "AbpHt": -16, 
             "CvpHt": 3, 
-            "EcgIIHt": 9, 
+            "EcgIIHt": -3, 
             "EcgTag": 0, 
-            "EcgV5Ht": 8, 
+            "EcgV5Ht": -2, 
             "PapHt": -14, 
             "SpHt": -17
         }, 
         {
             "AbpHt": -15, 
             "CvpHt": 2, 
-            "EcgIIHt": 9, 
+            "EcgIIHt": -3, 
             "EcgTag": 0, 
-            "EcgV5Ht": 7, 
+            "EcgV5Ht": -2, 
             "PapHt": -13, 
             "SpHt": -18
         }, 
         {
             "AbpHt": -14, 
             "CvpHt": 2, 
-            "EcgIIHt": 8, 
+            "EcgIIHt": -3, 
             "EcgTag": 0, 
-            "EcgV5Ht": 6, 
+            "EcgV5Ht": -2, 
             "PapHt": -12, 
             "SpHt": -19
         }, 
         {
             "AbpHt": -13, 
             "CvpHt": 1, 
-            "EcgIIHt": 5, 
+            "EcgIIHt": -3, 
             "EcgTag": 0, 
-            "EcgV5Ht": 4, 
+            "EcgV5Ht": -2, 
             "PapHt": -12, 
             "SpHt": -20
         }, 
         {
             "AbpHt": -12, 
             "CvpHt": 1, 
-            "EcgIIHt": 3, 
+            "EcgIIHt": -3, 
             "EcgTag": 0, 
-            "EcgV5Ht": 2, 
+            "EcgV5Ht": -2, 
             "PapHt": -12, 
             "SpHt": -20
         }, 
         {
             "AbpHt": -12, 
             "CvpHt": 0, 
-            "EcgIIHt": 1, 
+            "EcgIIHt": -2, 
             "EcgTag": 0, 
-            "EcgV5Ht": 1, 
+            "EcgV5Ht": -1, 
             "PapHt": -13, 
             "SpHt": -20
         }, 
         {
             "AbpHt": -12, 
             "CvpHt": 0, 
-            "EcgIIHt": 1, 
+            "EcgIIHt": -2, 
             "EcgTag": 0, 
-            "EcgV5Ht": 1, 
+            "EcgV5Ht": -1, 
             "PapHt": -13, 
             "SpHt": -20
         }, 
         {
             "AbpHt": -13, 
             "CvpHt": 0, 
-            "EcgIIHt": 1, 
+            "EcgIIHt": -1, 
             "EcgTag": 0, 
-            "EcgV5Ht": 1, 
+            "EcgV5Ht": -1, 
             "PapHt": -13, 
             "SpHt": -20
         }, 
         {
             "AbpHt": -13, 
             "CvpHt": 0, 
-            "EcgIIHt": 1, 
+            "EcgIIHt": -1, 
             "EcgTag": 0, 
             "EcgV5Ht": 0, 
             "PapHt": -12, 
@@ -822,6 +822,96 @@ st3[60] = {
             "PapHt": -5, 
             "SpHt": -4
         }, 
+        {
+            "AbpHt": -3, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -5, 
+            "SpHt": -4
+        }, 
+        {
+            "AbpHt": -3, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -5, 
+            "SpHt": -4
+        }, 
+        {
+            "AbpHt": -3, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -5, 
+            "SpHt": -4
+        }, 
+        {
+            "AbpHt": -3, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -5, 
+            "SpHt": -4
+        }, 
+        {
+            "AbpHt": -3, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -5, 
+            "SpHt": -4
+        }, 
+        {
+            "AbpHt": -3, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -5, 
+            "SpHt": -3
+        }, 
+        {
+            "AbpHt": -3, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -5, 
+            "SpHt": -3
+        }, 
+        {
+            "AbpHt": -3, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -5, 
+            "SpHt": -3
+        }, 
+        {
+            "AbpHt": -3, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -5, 
+            "SpHt": -4
+        }, 
+        {
+            "AbpHt": -3, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -5, 
+            "SpHt": -4
+        }, 
         {
             "AbpHt": -3, 
             "CvpHt": 0, 
@@ -898,10 +988,100 @@ st3[60] = {
             "AbpHt": -2, 
             "CvpHt": 0, 
             "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -4, 
+            "SpHt": -3
+        }, 
+        {
+            "AbpHt": -2, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -4, 
+            "SpHt": -3
+        }, 
+        {
+            "AbpHt": -2, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -4, 
+            "SpHt": -3
+        }, 
+        {
+            "AbpHt": -2, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -4, 
+            "SpHt": -3
+        }, 
+        {
+            "AbpHt": -2, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -3, 
+            "SpHt": -2
+        }, 
+        {
+            "AbpHt": -2, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -3, 
+            "SpHt": -2
+        }, 
+        {
+            "AbpHt": -2, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -3, 
+            "SpHt": -2
+        }, 
+        {
+            "AbpHt": -2, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -3, 
+            "SpHt": -2
+        }, 
+        {
+            "AbpHt": -1, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -3, 
+            "SpHt": -2
+        }, 
+        {
+            "AbpHt": -1, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -3, 
+            "SpHt": -2
+        }, 
+        {
+            "AbpHt": -1, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
             "EcgTag": 1, 
             "EcgV5Ht": 0, 
-            "PapHt": -4, 
-            "SpHt": -3
+            "PapHt": -3, 
+            "SpHt": -2
         }
     ]
 }
\ No newline at end of file
