@@ -22,11 +22,11 @@ function setDebugMode($enabled) {
 }
 
 // Log only if debug mode is enabled
-function logCaseSaveDebug($userId, $username, $userEmail, $grade, $score, $status, $errorType = null, $errorMsg = null, $insertId = null) {
+function logCaseSaveDebug($userId, $username, $email, $grade, $score, $status, $errorType = null, $errorMsg = null, $insertId = null, $caseName = null) {
     if (!isDebugModeEnabled()) {
         return;
     }
     
-    logCaseSave($userId, $username, $userEmail, $grade, $score, $status, $errorType, $errorMsg, $insertId);
+    logCaseSave($userId, $username, $email, $grade, $score, $status, $errorType, $errorMsg, $insertId, $caseName);
 }
 ?>
