@@ -131,12 +131,12 @@ if(isset($_POST['submitedit'])) {  // edit a group
 //:: 
       //:: now update the user_email in wp_users in case the admin's email has been changed
       //::
-      if ($_POST['group_email_hidden'] != $_POST['group_email']) {
+      if (strtolower($_POST['group_email_hidden']) != strtolower($_POST['group_email'])) {
           //::
           //:: 1. first try to find the old email in wp_uses
           //::
-          $group_old_email = $_POST['group_email_hidden']; 
-          $group_new_email = $_POST['group_email']; 
+          $group_old_email = strtolower($_POST['group_email_hidden']); 
+          $group_new_email = strtolower($_POST['group_email']); 
           
           $getUserEmail = "SELECT
                             user_email
@@ -262,7 +262,7 @@ if(isset($_POST['submitedit'])) {  // edit a group
               ':admin' => $_POST['group_admin'],
               ':pass' => $password,
               ':pass_clear' => $passwordClear,
-              ':email' => $_POST['group_email'],
+              ':email' => strtolower($_POST['group_email']),
               ':address' => $_POST['group_institution_address'],
               ':inst_name' => $_POST['expiration_date'],
               ':notes' => $_POST['group_notes'],
@@ -383,7 +383,7 @@ if(isset($_POST['submitnew'])){    // ------------------------ New Group -------
     try{
         $stmt = $pdo->prepare($registrationQuery);
         $result = $stmt->execute([
-            ':group_email' => $_POST['group_email'],
+            ':group_email' => strtolower($_POST['group_email']),
             ':password' => $password,
             ':group_name' => $_POST['group_name'],
             ':date2' => $date2
@@ -435,7 +435,7 @@ if(isset($_POST['submitnew'])){    // ------------------------ New Group -------
             ':group_admin' => $_POST['group_admin'],
             ':password' => $password,
             ':passwordClear' => $passwordClear,
-            ':group_email' => $_POST['group_email'],
+            ':group_email' => strtolower($_POST['group_email']),
             ':group_name' => $_POST['group_name'],
             ':group_institution_address' => $_POST['group_institution_address'],
             ':expiration_date' => $_POST['expiration_date'],
