@@ -57,6 +57,30 @@ if (!isset($_SESSION['front_user_id'])) {
     if (isDebugModeEnabled()) {
         logMessage2("ERROR: User session not found");
     }
+    
+    $caseGrade = isset($data['grade']) ? $data['grade'] : 'Unknown';
+    $caseLog = isset($data['caseLog']) ? $data['caseLog'] : '';
+    
+    // Use client-provided score and time if available (for session expired cases)
+    $caseScore = isset($data['clientCaseScore']) ? $data['clientCaseScore'] : '';
+    if (empty($caseScore)) {
+        preg_match('/(-?\d+\s*\/\s*\d+)/', $caseLog, $scoreMatches);
+        $caseScore = isset($scoreMatches[0]) ? $scoreMatches[0] : '';
+    }
+    $caseTime = isset($data['clientCaseTime']) ? $data['clientCaseTime'] : '';
+    
+    // fetch the real user info from the hidden fields
+    $clientUserId = isset($data['clientUserId']) ? $data['clientUserId'] : null;
+    $clientFirstName = isset($data['clientUserFirstName']) ? $data['clientUserFirstName'] : '';
+    $clientLastName = isset($data['clientUserLastName']) ? $data['clientUserLastName'] : '';
+    $clientUserName = trim($clientFirstName . ' ' . $clientLastName);
+    if (empty($clientUserName)) $clientUserName = 'Unknown';
+    $clientUserEmail = isset($data['clientUserEmail']) ? $data['clientUserEmail'] : 'Unknown';
+    
+    $caseTime = isset($data['clientCaseTime']) ? $data['clientCaseTime'] : '';
+    $caseName = isset($data['clientCaseName']) ? $data['clientCaseName'] : 'Unknown Case';
+    $errorDetails = 'User session not found' . ($caseTime ? ' | Case time: ' . $caseTime : '');
+    logCaseSaveDebug($clientUserId, $clientUserName, $clientUserEmail, $caseGrade, $caseScore, 'FAILED', 'SESSION_EXPIRED', $errorDetails, null, $caseName);
     $_SESSION['flash_message'] = ['type' => 'error', 'message' => 'Your session has expired. Please log in again and retry saving. If needed, open the case log, copy all text and save in a txt file or Word doc. Contact jill@website.com'];
     echo json_encode(["success" => false, "errorType" => "SESSION_EXPIRED", "message" => "User session expired."]);
     exit();
@@ -79,6 +103,20 @@ try {
     }
 }
 
+// Override with client data if available
+if (isset($data['clientUserId']) && !empty($data['clientUserId'])) {
+    $userId = $data['clientUserId'];
+}
+if (isset($data['clientUserFirstName']) && isset($data['clientUserLastName'])) {
+    $clientName = trim($data['clientUserFirstName'] . ' ' . $data['clientUserLastName']);
+    if (!empty($clientName)) {
+        $username = $clientName;
+    }
+}
+if (isset($data['clientUserEmail']) && !empty($data['clientUserEmail'])) {
+    $userEmail = $data['clientUserEmail'];
+}
+
 $caseLog = isset($data['caseLog']) ? $data['caseLog'] : '';
 $caseGrade = isset($data['grade']) ? $data['grade'] : 'Unknown';
 $instructorNotes = isset($data['instructor_notes']) ? $data['instructor_notes'] : null;
@@ -92,7 +130,8 @@ if (empty($caseLog)) {
     if (isDebugModeEnabled()) {
         logMessage2("ERROR: Empty case log provided");
     }
-    logCaseSaveDebug($userId, $username, $userEmail, $caseGrade, '', 'FAILED', 'VALIDATION_ERROR', 'Empty case log');
+    $errorDetails = 'Empty case log' . ($caseTime ? ' | Case time: ' . $caseTime : '');
+    logCaseSaveDebug($userId, $username, $userEmail, $caseGrade, '', 'FAILED', 'VALIDATION_ERROR', $errorDetails, null, $caseName);
     $_SESSION['flash_message'] = ['type' => 'error', 'message' => 'Invalid data detected in case log. Please review your entries and try again. If you need assistance, open the case log, copy all text and save in a txt file or Word doc. Contact jill@website.com'];
     echo json_encode(["success" => false, "errorType" => "VALIDATION_ERROR", "message" => "Case log cannot be empty."]);
     exit();
@@ -100,6 +139,14 @@ if (empty($caseLog)) {
 
 preg_match('/(-?\d+\s*\/\s*\d+)/', $caseLog, $scoreMatches);
 $caseScore = isset($scoreMatches[0]) ? $scoreMatches[0] : '';
+
+// Override with client data if available
+if (isset($data['clientCaseScore']) && !empty($data['clientCaseScore'])) {
+    $caseScore = $data['clientCaseScore'];
+}
+$caseTime = isset($data['clientCaseTime']) ? $data['clientCaseTime'] : '';
+$caseName = isset($data['clientCaseName']) ? $data['clientCaseName'] : 'Unknown Case';
+
 if (isDebugModeEnabled()) {
     logMessage2("Extracted score: " . ($caseScore ? $caseScore : "None found"));
 }
@@ -114,6 +161,11 @@ try {
         $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
     }
     
+    // Test mode: force database error
+    if (isset($data['forceError']) && $data['forceError'] === true) {
+        throw new PDOException("Test error: Simulated database failure");
+    }
+    
     if (isDebugModeEnabled()) {
         logMessage2("Database connection successful");
         logMessage2("Preparing SQL statement...");
@@ -142,7 +194,8 @@ try {
         logMessage2("=== CASE SAVE COMPLETED SUCCESSFULLY ===");
     }
     
-    logCaseSaveDebug($userId, $username, $userEmail, $caseGrade, $caseScore, 'SUCCESS', null, null, $insertedId);
+    $successDetails = 'Case time: ' . $caseTime;
+    logCaseSaveDebug($userId, $username, $userEmail, $caseGrade, $caseScore, 'SUCCESS', null, $successDetails, $insertedId, $caseName);
     
     $_SESSION['flash_message'] = ['type' => 'success', 'message' => 'Case log saved successfully.'];
     
@@ -188,7 +241,8 @@ try {
     if (isDebugModeEnabled()) {
         logMessage2("=== CASE SAVE FAILED ===");
     }
-    logCaseSaveDebug($userId, $username, $userEmail, $caseGrade, $caseScore, 'FAILED', $errorType, $errorMsg);
+    $errorDetails = $errorMsg . ($caseTime ? ' | Case time: ' . $caseTime : '');
+    logCaseSaveDebug($userId, $username, $userEmail, $caseGrade, $caseScore, 'FAILED', $errorType, $errorDetails, null, $caseName);
     
     $_SESSION['flash_message'] = ['type' => 'error', 'message' => $userMessage];
     
@@ -201,7 +255,8 @@ try {
         logMessage2("=== CASE SAVE FAILED ===");
     }
     
-    logCaseSaveDebug($userId, $username, $userEmail, $caseGrade, $caseScore, 'FAILED', 'GENERAL_ERROR', $e->getMessage());
+    $errorDetails = $e->getMessage() . ($caseTime ? ' | Case time: ' . $caseTime : '');
+    logCaseSaveDebug($userId, $username, $userEmail, $caseGrade, $caseScore, 'FAILED', 'GENERAL_ERROR', $errorDetails, null, $caseName);
     
     $_SESSION['flash_message'] = ['type' => 'error', 'message' => 'An unexpected error occurred. Please try again. If the problem persists, open the case log, copy all text and save in a txt file or Word doc. Contact jill@website.com'];
     
