@@ -68,11 +68,11 @@ document.addEventListener('DOMContentLoaded', () => {
 		
 		fetch('/api/get_user_cases.php' + (showHidden ? '?show_hidden=1' : ''))
 			.then(response => {
-				console.log("Response received:", response.status);
+				// console.log("Response received:", response.status);
 				return response.text();
 			})
 			.then(data => {
-				console.log("Data received:", data);
+				// console.log("Data received:", data);
 				document.getElementById('cases-list').innerHTML = data;
 				document.getElementById('cases-list').style.display = 'block';
 				document.getElementById('case-details').style.display = 'none';
@@ -86,7 +86,7 @@ document.addEventListener('DOMContentLoaded', () => {
 				}
 			})
 			.catch(error => {
-				console.error('Error loading cases:', error);
+				// console.error('Error loading cases:', error);
 				document.getElementById('cases-list').innerHTML = '<p>Error loading cases. Please try again later.</p>';
 			});
 	}
@@ -113,7 +113,7 @@ document.addEventListener('DOMContentLoaded', () => {
 					}
 				})
 				.catch(error => {
-					console.error('Error:', error);
+					// console.error('Error:', error);
 					alert('Error communicating with server');
 				});
 			});
@@ -130,7 +130,7 @@ document.addEventListener('DOMContentLoaded', () => {
                 updateBreadcrumbs('View Cases', caseId);
             })
             .catch(error => {
-                console.error('Error loading case details:', error);
+                // console.error('Error loading case details:', error);
                 document.getElementById('case-details').innerHTML = '<p>Error loading case details. Please try again later.</p>';
             });
     }
@@ -169,4 +169,4 @@ document.addEventListener('DOMContentLoaded', () => {
             showViewCases();
         }
     });
-});
\ No newline at end of file
+});
